<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\ErasmusParticipant;
use App\ErasmusProgramme;
use App\ErasmusProgrammeParticipant;
use App\Katigories;
use App\Parameter;
use PDF;
use Carbon\Carbon;
use Illuminate\Support\Facades\File;

class ErasmusParticipantController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $participants = ErasmusParticipant::all();
		return view('erasmusParticipants.index',
				compact('participants'));    

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('erasmusParticipants.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
		$participant = $request->all();        	
		$id = ErasmusParticipant::create($participant)->id; 
		return redirect('erasmusParticipants/show/'.$id);  
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        	$participant = ErasmusParticipant::find($id);       
            $participantProgrammes = ErasmusParticipant::find($id)->erasmusProgrammeParticipant;		
			return view('erasmusParticipants.show', compact('participant', 'participantProgrammes')); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $participant = ErasmusParticipant::find($id);  
		return view('erasmusParticipants.edit', compact('participant')); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $participantUpdate = $request->all();
		$participant = ErasmusParticipant::find($id);
		$participant->update($participantUpdate);
  	    return redirect('erasmusParticipants/show/'.$id); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $participant = ErasmusParticipant::find($id)->delete();
		return redirect('participants');
    }

    /**
     * Programme-Students funcions
     *
     */


    public function createProgramme($participant_id) 
    {
		$programmesList = ErasmusProgramme::where('confirmed', null)
			->orderBy('start_date', 'desc')->pluck('code', 'id');
        return view('erasmusParticipants.createProgramme', compact('participant_id', 'programmesList'));
    }

    public function storeProgramme(Request $request)
    {
        
        $programmeParticipant = $request->all();
		if ($programmeParticipant['days'] == 0) {
			$days = ErasmusProgramme::find($request->programme_id)->days;
			$programmeParticipant['days'] = $days;
		}
		if ($programmeParticipant['start_date'] == NULL) {
			$startDate = ErasmusProgramme::find($request->programme_id)->start_date;
			$programmeParticipant['start_date'] = $startDate;
		}
		if ($programmeParticipant['certificate_number'] == 0) {
			$cid = ErasmusProgrammeParticipant::max('id');
			$programmeParticipant['certificate_number'] = $cid + 7001;
		}

		ErasmusProgrammeParticipant::create($programmeParticipant);        
		return redirect('erasmusParticipants/show/'.$request->participant_id);
    }

    public function editProgramme($id)
    {
        $participantProgramme = ErasmusProgrammeParticipant::find($id);
		$programmesList = ErasmusProgramme::orderBy('start_date')->pluck('code', 'id');
		return view('erasmusParticipants.editProgramme', compact('participantProgramme', 'programmesList')); 
    }

    public function updateProgramme(Request $request, $id)
    {
        $participantUpdate = $request->all();
		$ProgrammeParticipant = ErasmusProgrammeParticipant::find($id);
		$ProgrammeParticipant->update($participantUpdate);
		return redirect('erasmusParticipants/show/'.$ProgrammeParticipant->participant_id); 
    }

    public function destroyProgramme($id, $participant_id)
    {
        $programmeParticipant = ErasmusProgrammeParticipant::find($id)->delete();
		return redirect('erasmusParticipants/show/'.$participant_id); 
    }

    public function printCertificate($id, $participant_id)
    {
		$studentProgramme = ErasmusProgrammeParticipant::leftjoin('erasmus_programmes', 'erasmus_programmes.id', '=', 'erasmus_programmes_participants.programme_id')
		->select('erasmus_programmes.city', 'erasmus_programmes.code', 'erasmus_programmes.title_certificate', 'erasmus_programmes_participants.*')
		->find($id);
		$endDate = Carbon::createFromFormat('Y-m-d', $studentProgramme->start_date);
		$endDate = $endDate->addDays($studentProgramme->days-1);



        $participant = ErasmusParticipant::find($participant_id);  

		$pdf = PDF::loadView('pdf.certificate-ka1', compact('studentProgramme', 'participant', 'endDate'));
		$pdf->setPaper('A4', 'landscape');
		$pdf->getDomPDF()->set_option('enable_html5_parser', true);
		//return $pdf->download('certificate-'.$participant->lastname.'.pdf');	
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;

    }

    public function printEuropass($id, $participant_id)
    {
		$studentProgramme = ErasmusProgrammeParticipant::leftjoin('erasmus_programmes', 'erasmus_programmes.id', '=', 'erasmus_programmes_participants.programme_id')
		->select('erasmus_programmes.city', 'erasmus_programmes.code', 'erasmus_programmes.title_certificate', 'erasmus_programmes_participants.*')
		->find($id);
		$endDate = Carbon::createFromFormat('Y-m-d', $studentProgramme->start_date);
		$endDate = $endDate->addDays($studentProgramme->days-1);



        $participant = ErasmusParticipant::find($participant_id);  

        $cid_3 = substr($studentProgramme->code, 0, 3);
        if ($cid_3 == 'Inc') {
            $pdf = PDF::loadView('pdf.inclusive', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'ICT') {
            $pdf = PDF::loadView('pdf.ict', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'CLI') {
            $pdf = PDF::loadView('pdf.clil', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'Mus') {
            $pdf = PDF::loadView('pdf.museum', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'Div') {
            $pdf = PDF::loadView('pdf.diversity', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'Spe') {
            $pdf = PDF::loadView('pdf.sne', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'Man') {
            $pdf = PDF::loadView('pdf.management', compact('studentProgramme', 'participant', 'endDate'));
        } else if ($cid_3 == 'Mel') {
            $pdf = PDF::loadView('pdf.melodic', compact('studentProgramme', 'participant', 'endDate'));
        }
         else {
            $pdf = PDF::loadView('pdf.inclusive', compact('studentProgramme', 'participant', 'endDate'));
        }
		
		$pdf->setPaper('A4', 'portrait');
		$pdf->getDomPDF()->set_option('enable_html5_parser', true);
		//return $pdf->download('certificate-'.$participant->lastname.'.pdf');	
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;

    }


    /**
     * Programme-Payment funcions
     *
     */


   

}
