<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Student;
use App\Programme;
use App\ProgrammeStudent;
use App\Katigories;
use App\Parameter;
use App\StudentPayment;
use PDF;
use Carbon\Carbon;
use Illuminate\Support\Facades\File;

class StudentController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth');
    }


    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $students = Student::all();
		return view('students.index',
				compact('students'));    

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('students.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
		$student = $request->all();        	
		Student::create($student);        
		return redirect('students');    
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        	$student = Student::find($id);       
			$studentProgrammes = ProgrammeStudent::leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
			->select('programmes.code', 'programmes.title', 'programmes.price as programme_price', 'programmes.ores_sum', 'programmes.place', 'programme_students.*')
			->where('student_id', $id)
            ->get();
			$studentPayments = StudentPayment::leftjoin('programme_students', 'student_payments.programme_student_id', '=', 'programme_students.id')
			->leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
			->select('programmes.title', 'student_payments.*')
			->where('programme_students.student_id', $id)
            ->get();

//			return view('students.show', ['student'=>$student, 'studentProgrammes'=>$studentProgrammes]); 
			return view('students.show', compact('student', 'studentProgrammes', 'studentPayments')); 

    }

	public function indexVevaioseis()
    {
        $studentVevaioseis = ProgrammeStudent::whereNotNull('certificate_number')
            ->get();
		return view('students.indexVevaioseis', compact('studentVevaioseis'));    

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $student = Student::find($id);
		return view('students.edit', compact('student')); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $studentUpdate = $request->all();
		$student = Student::find($id);
		$student->update($studentUpdate);
  	    return redirect('students/show/'.$id); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $student = Student::find($id)->delete();
		return redirect('students');
    }

    /**
     * Programme-Students funcions
     *
     */


    public function createProgramme($student_id) 
    {
		$programmesList = Programme::orderBy('title')->pluck('title', 'id');
        return view('students.createProgramme', compact('student_id', 'programmesList'));
    }

    public function storeProgramme(Request $request)
    {
        
        $programmestudent = $request->all();
		if ($request->certificate_number == 0) {
			$nextNumber = ProgrammeStudent::max('certificate_number');
			$programmestudent['certificate_number'] = $nextNumber + 1;
		}
		ProgrammeStudent::create($programmestudent);        
		return redirect('students/show/'.$request->student_id);
    }

    public function editProgramme($id)
    {
        $studentProgramme = ProgrammeStudent::find($id);
		$programmesList = Programme::orderBy('title')->pluck('title', 'id');
		return view('students.editProgramme', compact('studentProgramme', 'programmesList')); 
    }

    public function updateProgramme(Request $request, $id)
    {
        $studentUpdate = $request->all();
		$ProgrammeStudent = ProgrammeStudent::find($id);
		$ProgrammeStudent->update($studentUpdate);
		return redirect('students/show/'.$ProgrammeStudent->student_id); 
    }

    public function destroyProgramme($id, $student_id)
    {
        $programmeStudent = ProgrammeStudent::find($id)->delete();
		return redirect('students/show/'.$student_id); 
    }

    public function printCertificate($id, $student_id)
    {
//        $studentProgramme = ProgrammeStudent::find($id);
		$studentProgramme = ProgrammeStudent::leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
		->select('programmes.code', 'programmes.city', 'programme_students.*')
		->find($id);



		$student = Student::find($student_id);
		$pdf = PDF::loadView('pdf.certificate', compact('studentProgramme', 'student'));
		$pdf->setPaper('A4', 'landscape');
		//return $pdf->download('certificate-'.$student->lastname.'.pdf');
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;		
    }

    public function printGreekEuropass($id, $student_id)
    {
		$studentProgramme = ProgrammeStudent::leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
		->select('programmes.code', 'programmes.city', 'programme_students.*')
		->find($id);
		$endDate = Carbon::createFromFormat('Y-m-d', $studentProgramme->certificate_date);
		
        $student = Student::find($student_id);

        $cid_3 = substr($studentProgramme->code, 0, 3);
        if ($studentProgramme->code == 'ek_en_sde' && $studentProgramme->ores_real==600) {
            $pdf = PDF::loadView('pdf_gr.ek_en_sde600', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_sde' && $studentProgramme->ores_real==800) {
            $pdf = PDF::loadView('pdf_gr.ek_en_sde800', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_sde' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_sde200', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_sde' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_sde300', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_sde' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_sde400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_thesm' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_thesm200', compact('studentProgramme', 'student', 'endDate'));    
        } else if ($studentProgramme->code == 'ek_en_thesm' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_thesm300', compact('studentProgramme', 'student', 'endDate'));    
        } else if ($studentProgramme->code == 'ek_en_thesm' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_thesm400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_thesm' && $studentProgramme->ores_real==600) {
            $pdf = PDF::loadView('pdf_gr.ek_en_thesm600', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_thesm' && $studentProgramme->ores_real==800) {
            $pdf = PDF::loadView('pdf_gr.ek_en_thesm800', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_basic' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_basic200', compact('studentProgramme', 'student', 'endDate')); 
        } else if ($studentProgramme->code == 'ek_en_basic' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_basic300', compact('studentProgramme', 'student', 'endDate'));               
        } else if ($studentProgramme->code == 'ek_en_basic' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_basic400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_basic' && $studentProgramme->ores_real==600) {
            $pdf = PDF::loadView('pdf_gr.ek_en_basic600', compact('studentProgramme', 'student', 'endDate'));        
        } else if ($studentProgramme->code == 'ek_en_basic' && $studentProgramme->ores_real==800) {
            $pdf = PDF::loadView('pdf_gr.ek_en_basic800', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_progSDE' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_progSDE200', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_progSDE' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_progSDE300', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_progSDE' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_progSDE400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_prog' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_prog200', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_prog' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_prog300', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_prog' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_prog400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_eidikeush' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_eidikeush200', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_eidikeush' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_eidikeush300', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_eidikeush' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_eidikeush400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_eidikeush' && $studentProgramme->ores_real==600) {
            $pdf = PDF::loadView('pdf_gr.ek_en_eidikeush600', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_eidikeush' && $studentProgramme->ores_real==800) {
            $pdf = PDF::loadView('pdf_gr.ek_en_eidikeush800', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_mng' && $studentProgramme->ores_real==200) {
            $pdf = PDF::loadView('pdf_gr.ek_en_mng200', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_mng' && $studentProgramme->ores_real==300) {
            $pdf = PDF::loadView('pdf_gr.ek_en_mng300', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_mng' && $studentProgramme->ores_real==400) {
            $pdf = PDF::loadView('pdf_gr.ek_en_mng400', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_mng' && $studentProgramme->ores_real==600) {
            $pdf = PDF::loadView('pdf_gr.ek_en_mng600', compact('studentProgramme', 'student', 'endDate'));
        } else if ($studentProgramme->code == 'ek_en_mng' && $studentProgramme->ores_real==800) {
            $pdf = PDF::loadView('pdf_gr.ek_en_mng800', compact('studentProgramme', 'student', 'endDate'));
        } else if ($cid_3 == 'Mel') {
            $pdf = PDF::loadView('pdf.melodic', compact('studentProgramme', 'participant', 'endDate'));
        }
         else {
            $pdf = PDF::loadView('pdf.inclusive', compact('studentProgramme', 'participant', 'endDate'));
        }
		
		$pdf->setPaper('A4', 'portrait');
		$pdf->getDomPDF()->set_option('enable_html5_parser', true);
		//return $pdf->download('certificate-'.$participant->lastname.'.pdf');	
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;

    }

    /**
     * Programme-Payment funcions
     *
     */


    public function createPayment($student_id) 
    {
		$kindList = Katigories::where('kod_katigoria', 51)
			->orderBy('onomasia')->pluck('onomasia', 'id');
		$typeList = Katigories::where('kod_katigoria', 52)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');
		$programmesList = ProgrammeStudent::leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
		->select('programmes.title', 'programmes.price as programme_price', 'programmes.ores_sum', 'programmes.place', 'programme_students.*')
		->where('student_id', $student_id)
		->orderBy('title')
		->pluck('title', 'id');

        return view('students.createPayment', compact('student_id', 'programmesList', 'kindList', 'typeList'));
    }

    public function storePayment(Request $request)
    {
		$studentPayment = $request->all();
		$paymentKind = Katigories::find($request->payment_kind_id);
		$studentPayment['payment_kind'] = $paymentKind->onomasia;
		if ($request->payment_number == 0) {
			$nextPayment = StudentPayment::where('payment_kind_id', $request->payment_kind_id)
				->where('payment_date', '>=', '2019-02-17')
				->max('payment_number');
			$studentPayment['payment_number'] = $nextPayment + 1;
		}
		StudentPayment::create($studentPayment);        
		return redirect('students/show/'.$request->student_id);
    }

    public function editPayment($id, $student_id)
    {
        $studentPayment = StudentPayment::find($id);
		$programmesList = ProgrammeStudent::leftjoin('programmes', 'programmes.id', '=', 'programme_students.programme_id')
		->select('programmes.title', 'programmes.price as programme_price', 'programmes.ores_sum', 'programmes.place', 'programme_students.*')
		->where('student_id', $student_id)
		->orderBy('title')
		->pluck('title', 'id');
		$kindList = Katigories::where('kod_katigoria', 51)
			->orderBy('onomasia')->pluck('onomasia', 'id');
		$typeList = Katigories::where('kod_katigoria', 52)
			->orderBy('onomasia')->pluck('onomasia', 'onomasia');

		return view('students.editPayment', compact('studentPayment', 'student_id', 'programmesList', 'kindList', 'typeList')); 
    }

    public function updatePayment(Request $request, $id)
    {
        $studentUpdate = $request->all();
		$paymentKind = Katigories::find($request->payment_kind_id);
		$studentUpdate['payment_kind'] = $paymentKind->onomasia;
		$studentPayment = StudentPayment::find($id);
		$studentPayment->update($studentUpdate);
		return redirect('students/show/'.$request->student_id); 
    }

    public function destroyPayment($id, $student_id)
    {
        $StudentPayment = StudentPayment::find($id)->delete();
		return redirect('students/show/'.$student_id); 
    }

    public function printPayment($id, $student_id)
    {
        $studentPayment = StudentPayment::find($id);
		$student = Student::find($student_id);
		if ($studentPayment->payment_kind_id == 1) {
			$pdf = PDF::loadView('pdf.invoice', compact('studentPayment', 'student'));
		}
		else {
			$pdf = PDF::loadView('pdf.invoice_company', compact('studentPayment', 'student'));
		}
//		return $pdf->download('invoice'.$student->lastname.'.pdf');	
		$match_files = File::glob('document*');
		if($match_files !== false) {
			foreach($match_files as $file) {
			if(file_exists($file))
			File::delete($file);
			}
		}
		$output = $pdf->output();
		$newfile = 'document'.strval(rand(0, 9999990)).'.pdf';
		file_put_contents($newfile, $output);
		echo $newfile;


    }

}
